
`packetmq` - Packet based networking
====================================

.. image:: https://readthedocs.org/projects/packetmq/badge/?version=latest
   :target: http://packetmq.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/dd/packetmq.svg
   :target: https://pypi.python.org/pypi?name=packetmq&:action=display
   :alt: PyPi

.. image:: https://landscape.io/github/not-na/packetmq/master/landscape.svg?style=flat
   :target: https://landscape.io/github/not-na/packetmq/master
   :alt: Code Health

.. image:: https://travis-ci.org/not-na/packetmq.svg?branch=master
   :target: https://travis-ci.org/not-na/packetmq

.. image:: https://coveralls.io/repos/not-na/packetmq/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/not-na/packetmq?branch=master

`packetmq` allows fast and asynchronous packet-based networking.
`packetmq` uses twisted and msgpack for networking and serialization, respectively.

Twisted allows fast and asynchronous data transfer, while msgpack allows fast and compact encoding/serialization.
